.. _contribissue:

File an Issue
=============

If you have found a bug or problem in Arbor, or want to request a feature, you
can use our `issue tracker <https://github.com/arbor-sim/arbor/issues>`__. If
your issue is not yet filed in the issue tracker, please do so and describe the
problem, bug, or feature as best you can. You can add supporting data, code, or
documents to help make your point. For bugs in particular, stack traces (either
from inside a debugger or by enabling ``ARB_BACKTRACE``) are extremely useful.
